slepc-3.18.0 2022-10-01
Report Typos and Errors

# BVOrthogonalizeVec

Orthogonalize a given vector with respect to all active columns.

### Synopsis

    #include "slepcbv.h"
    PetscErrorCode BVOrthogonalizeVec(BV bv,Vec v,PetscScalar *H,PetscReal *norm,PetscBool *lindep)

Collective on bv

### Input Parameters

| bv | - the basis vectors context
| v | - the vector

### Output Parameters

| H | - (optional) coefficients computed during orthogonalization
| norm | - (optional) norm of the vector after being orthogonalized
| lindep | - (optional) flag indicating that refinement did not improve the quality of orthogonalization

### Notes

This function is equivalent to BVOrthogonalizeColumn() but orthogonalizes a vector as an argument rather than taking one of the BV columns. The vector is orthogonalized against all active columns (k) and the constraints. If H is given, it must have enough space to store k-l coefficients, where l is the number of leading columns.

In the case of an indefinite inner product, the lindep parameter is not computed (set to false).

### See Also

BVOrthogonalizeColumn(), BVSetOrthogonalization(), BVSetActiveColumns(), BVGetNumConstraints()

### Level

advanced

### Location

src/sys/classes/bv/interface/bvorthog.c
Index of all BV routines
Table of Contents for all manual pages
Index of all manual pages